crystal_toolkit.renderables.volumetric module — Crystal Toolkit documentation

# crystal_toolkit.renderables.volumetric module

crystal_toolkit.renderables.volumetric.get_isosurface_scene(self, data_key='total', isolvl=0.05, step_size=4, origin=None, **kwargs)

  Get the isosurface from a VolumetricData object

  Parameters

    - data_key (str, optional) – Use the volumetric data from self.data[data_key]. Defaults to ‘total’.

    - isolvl (float, optional) – The cutoff for the isosurface to using the same units as VESTA so

    - independent (e/bohr and kept grid size) –

    - step_size (int, optional) – step_size parameter for marching_cubes_lewiner. Defaults to 3.

  Returns

    [description]

  Return type

    [type]

crystal_toolkit.renderables.volumetric.get_volumetric_scene(self, data_key='total', isolvl=0.02, step_size=3, **kwargs)

  Get the Scene object which contains a structure and a isosurface components

  Parameters

    - data_key (str, optional) – Use the volumetric data from self.data[data_key]. Defaults to ‘total’.

    - isolvl (float, optional) – The cuoff for the isosurface to using the same units as VESTA so e/bhor

    - independent (and kept grid size) –

    - step_size (int, optional) – step_size parameter for marching_cubes_lewiner. Defaults to 3.

    - **kwargs – kwargs for the Structure.get_scene function

  Returns

    [description]

  Return type

    [type]